==> simsu-1.3.1-1-src.tar.xz: simsu-1.3.1/translations/simsu_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="81"/>
        <location filename="../src/board.cpp" line="96"/>
        <source>Success</source>
        <translation>Успех</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="52"/>
        <source>Select application language:</source>
        <translation>Изберете езика на приложението:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="55"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Системен език&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="175"/>
        <source>Note</source>
        <translation>Бележка</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="175"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Моля, рестартирайте приложението за да влезе в сила промяната на езика.</translation>
    </message>
</context>
<context>
    <name>Pattern</name>
    <message>
        <location filename="../src/pattern.h" line="78"/>
        <source>180° Rotational</source>
        <translation>Ротационен на 180° </translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="79"/>
        <source>Full Rotational</source>
        <translation>Пълна ротация</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="80"/>
        <source>Horizontal</source>
        <translation>Хоризонтален</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="81"/>
        <source>Vertical</source>
        <translation>Вертикален </translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="82"/>
        <source>Horizontal &amp; Vertical</source>
        <translation>Хоризонтален &amp; Вертикален</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="83"/>
        <source>Diagonal</source>
        <translation>Диагонален</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="84"/>
        <source>Anti-Diagonal</source>
        <translation>Антидиагонален</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="85"/>
        <source>Diagonal &amp; Anti-Diagonal</source>
        <translation>Диагонален &amp; Антидиагонален</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="86"/>
        <source>Full Dihedral</source>
        <translation>Пълен двустенен</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="87"/>
        <source>Random</source>
        <translation>Произволен</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="88"/>
        <source>None</source>
        <translation>Никакъв</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/main.cpp" line="37"/>
        <location filename="../src/window.cpp" line="319"/>
        <source>Simsu</source>
        <translation>Simsu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="104"/>
        <source>Pen</source>
        <translation>Писалка</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="108"/>
        <source>Pencil</source>
        <translation>Молив </translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="112"/>
        <source>Highlight</source>
        <translation>Осветяване</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="114"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="121"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="158"/>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="159"/>
        <source>&amp;New</source>
        <translation>&amp;Нова</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="160"/>
        <source>&amp;Details</source>
        <translation>&amp;Детайли</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="162"/>
        <source>&amp;Quit</source>
        <translation>&amp;Изход</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="165"/>
        <source>&amp;Move</source>
        <translation>&amp;Ход</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="166"/>
        <source>&amp;Undo</source>
        <translation>&amp;Отмяна</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="168"/>
        <source>&amp;Redo</source>
        <translation>&amp;Връщане</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <source>&amp;Check</source>
        <translation>&amp;Проверка</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="174"/>
        <source>&amp;Auto Switch Modes</source>
        <translation>&amp;Режим на автом. превключване</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="178"/>
        <source>&amp;Widescreen Layout</source>
        <translation>&amp;Широкоекранен формат</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="183"/>
        <source>Application &amp;Language...</source>
        <translation>Език на приложението...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="185"/>
        <source>&amp;Help</source>
        <translation>&amp;Помощ</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="186"/>
        <source>&amp;Controls</source>
        <translation>&amp;Команди</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="189"/>
        <source>&amp;About</source>
        <translation>&amp;За програмата</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="191"/>
        <source>About &amp;Qt</source>
        <translation>За &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="233"/>
        <source>New Game</source>
        <translation>Нова игра</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="250"/>
        <location filename="../src/window.cpp" line="291"/>
        <source>Dancing Links</source>
        <translation>Танцуващи препратки</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="251"/>
        <location filename="../src/window.cpp" line="291"/>
        <source>Slice and Dice</source>
        <translation>Накълцано на пърчета </translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="256"/>
        <source>Random</source>
        <translation>Произволна</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="264"/>
        <source>Symmetry:</source>
        <translation>Симетрия</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="265"/>
        <source>Algorithm:</source>
        <translation>Алгоритъм: </translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="266"/>
        <source>Seed:</source>
        <translation>Семе:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="294"/>
        <source>Details</source>
        <translation>Детайли </translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="294"/>
        <source>&lt;p&gt;&lt;b&gt;Symmetry:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Симетрия:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Алгоритъм:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Семе:&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="303"/>
        <source>Controls</source>
        <translation>Команди</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="303"/>
        <source>&lt;p&gt;&lt;big&gt;&lt;b&gt;Mouse Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Left click:&lt;/b&gt; Toggle number in pen mode&lt;br&gt;&lt;b&gt;Right click:&lt;/b&gt; Toggle number in pencil mode&lt;br&gt;&lt;b&gt;Scrollwheel:&lt;/b&gt; Change current number&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Keyboard Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Arrow keys:&lt;/b&gt; Move selection&lt;br&gt;&lt;b&gt;Number keys:&lt;/b&gt; Toggle value or note&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Switch between pen and pencil modes&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Highlight all instances of current number&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;big&gt;&lt;b&gt;Контроли на мишката:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Ляв бутон:&lt;/b&gt; Превключване в режим писалка&lt;br&gt;&lt;b&gt;Десен бутон:&lt;/b&gt; Превключване в режим молив&lt;br&gt;&lt;b&gt;Скрол колело:&lt;/b&gt; Промяна на текущата цифра&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Контроли на клавиатурата:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Стрелки:&lt;/b&gt; Избор на квадратчето&lt;br&gt;&lt;b&gt;Цифрови клавиши:&lt;/b&gt; Превключване на цифрите&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Превключване между режим писалка и молив&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Осветяване на квадратчетата с текущата цифра&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="318"/>
        <source>About Simsu</source>
        <translation>За Simsu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="320"/>
        <source>A basic Sudoku game</source>
        <translation>Класическа игра Судоку</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="321"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="322"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Разпространява се под &lt;a href=%1&gt;GPL 3&lt;/a&gt; лиценс </translation>
    </message>
</context>
</TS>

==> simsu-1.3.4-1-src.tar.xz: simsu-1.3.4/translations/simsu_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Success</source>
        <translation>Успех</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Изберете езика на приложението:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Системен език&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Бележка</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Моля, рестартирайте приложението, за да влезе в сила промяната на езика.</translation>
    </message>
</context>
<context>
    <name>Pattern</name>
    <message>
        <source>180° Rotational</source>
        <translation>Осева на 180°</translation>
    </message>
    <message>
        <source>Full Rotational</source>
        <translation>Изцяло осева</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Хоризонтална</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Вертикална</translation>
    </message>
    <message>
        <source>Horizontal &amp; Vertical</source>
        <translation>Хоризонтална &amp; Вертикална</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Диагонална</translation>
    </message>
    <message>
        <source>Anti-Diagonal</source>
        <translation>Обратно-диагонална</translation>
    </message>
    <message>
        <source>Diagonal &amp; Anti-Diagonal</source>
        <translation>Диагонална и обратно диагонална</translation>
    </message>
    <message>
        <source>Full Dihedral</source>
        <translation>Напълно двустенна</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Произволна</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Никаква</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Simsu</source>
        <translation>Симсу</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Писалка</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Молив </translation>
    </message>
    <message>
        <source>Highlight</source>
        <translation>Осветяване</translation>
    </message>
    <message>
        <source>H</source>
        <translation>О</translation>
    </message>
    <message>
        <source>S</source>
        <translation>П</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Нова</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Подробности</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Изход</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Ход</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Отмяна</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Повторение</translation>
    </message>
    <message>
        <source>&amp;Check</source>
        <translation>П&amp;роверка</translation>
    </message>
    <message>
        <source>C</source>
        <translation>П</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>&amp;Auto Switch Modes</source>
        <translation>&amp;Авт. превключване на режима</translation>
    </message>
    <message>
        <source>&amp;Widescreen Layout</source>
        <translation>&amp;Широкоекранен формат</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Език на приложението...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощ</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Управление</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;За програмата</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>За &amp;Qt</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Нова игра</translation>
    </message>
    <message>
        <source>Dancing Links</source>
        <translation>Танцуващи връзки</translation>
    </message>
    <message>
        <source>Slice and Dice</source>
        <translation>Накълцано на парчета</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Произволна</translation>
    </message>
    <message>
        <source>Symmetry:</source>
        <translation>Симетрия</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Алгоритъм: </translation>
    </message>
    <message>
        <source>Seed:</source>
        <translation>Семе:</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Подробности</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Symmetry:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Симетрия:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Алгоритъм:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Семе:&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Управление</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;big&gt;&lt;b&gt;Mouse Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Left click:&lt;/b&gt; Toggle number in pen mode&lt;br&gt;&lt;b&gt;Right click:&lt;/b&gt; Toggle number in pencil mode&lt;br&gt;&lt;b&gt;Scrollwheel:&lt;/b&gt; Change current number&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Keyboard Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Arrow keys:&lt;/b&gt; Move selection&lt;br&gt;&lt;b&gt;Number keys:&lt;/b&gt; Toggle value or note&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Switch between pen and pencil modes&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Highlight all instances of current number&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;big&gt;&lt;b&gt;Управление с мишката:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Ляв бутон:&lt;/b&gt; Превкл. на цифрата в режим писалка&lt;br&gt;&lt;b&gt;Десен бутон:&lt;/b&gt; Превкл. на цифрата в режим молив&lt;br&gt;&lt;b&gt;Колелце:&lt;/b&gt; Промяна на текущата цифра&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Управление с клавиатурата:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Стрелки:&lt;/b&gt; Избор на квадратче&lt;br&gt;&lt;b&gt;Цифрови клавиши:&lt;/b&gt; Превключване на стойността или бележката&lt;br&gt;&lt;b&gt;П:&lt;/b&gt; Превключване между режим писалка и молив&lt;br&gt;&lt;b&gt;О:&lt;/b&gt; Осветяване на квадратчетата с текущата цифра&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About Simsu</source>
        <translation>За Симсу</translation>
    </message>
    <message>
        <source>A basic Sudoku game</source>
        <translation>Простичка игра от тип Судоку</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Разпространява се под лиценза &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
